summaryrefslogtreecommitdiff
path: root/sc/source/ui/view/viewfun2.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sc/source/ui/view/viewfun2.cxx')
-rw-r--r--sc/source/ui/view/viewfun2.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sc/source/ui/view/viewfun2.cxx b/sc/source/ui/view/viewfun2.cxx
index 4a69e92182b0..bd0fb122e88a 100644
--- a/sc/source/ui/view/viewfun2.cxx
+++ b/sc/source/ui/view/viewfun2.cxx
@@ -2343,14 +2343,14 @@ void ScViewFunc::MoveTable(
{
nDestTab = 0; // firstly insert
// execute without SFX_CALLMODE_RECORD, because already contained in move command
OUString aUrl("private:factory/" STRING_SCAPP);
SfxStringItem aItem( SID_FILE_NAME, aUrl );
SfxStringItem aTarget( SID_TARGETNAME, OUString("_blank") );
const SfxPoolItem* pRetItem = GetViewData().GetDispatcher().Execute(
- SID_OPENDOC, SFX_CALLMODE_API|SFX_CALLMODE_SYNCHRON, &aItem, &aTarget, 0L );
+ SID_OPENDOC, SfxCallMode::API|SfxCallMode::SYNCHRON, &aItem, &aTarget, 0L );
if ( pRetItem )
{
if ( pRetItem->ISA( SfxObjectItem ) )
@@ -2343,14 +2343,14 @@ void ScViewFunc::MoveTable(
{
nDestTab = 0; // firstly insert
- // execute without SFX_CALLMODE_RECORD, because already contained in move command
+ // execute without SfxCallMode::RECORD, because already contained in move command
OUString aUrl("private:factory/" STRING_SCAPP);
SfxStringItem aItem( SID_FILE_NAME, aUrl );